#
# spec file for package mksusecd
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014 Steffen Winterfeldt
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mksusecd
Version:        3.5
Release:        1.2
Summary:        Tool to create SUSE Linux installation ISOs
License:        GPL-3.0+
Group:          Hardware/Other
URL:            https://github.com/wfeldt/mksusecd
Source:         %{name}-%{version}.tar.xz
BuildRequires:  libuuid-devel
BuildRequires:  xz
%if 0%?suse_version >= 1500 || 0%?sle_version >= 120400
BuildRequires:  rubygem(asciidoctor)
%else
BuildRequires:  asciidoc
%if 0%?suse_version >= 1310 || 0%?sle_version >= 120000
BuildRequires:  libxslt-tools
%endif
%endif
Requires:       checkmedia >= 6.0
%if %suse_version >= 1500
Requires:       createrepo-implementation
Requires:       mkisofs
%else
Requires:       createrepo
Requires:       genisoimage
%endif
Requires:       dosfstools
Requires:       gpg2
Requires:       mtools
Requires:       squashfs
Requires:       xz
Requires:       perl-JSON
BuildRequires:  pkgconfig(blkid)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(json-c)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is a tool to create SUSE Linux installation ISOs.

%prep
%setup -q

%build

%install
make DESTDIR=%{buildroot} LIBDIR=%{_libexecdir} BINDIR=%{_bindir} install %{?_smp_mflags}
install -D -m 644 mksusecd.1 %{buildroot}%{_mandir}/man1/mksusecd.1
install -D -m 644 verifymedia.1 %{buildroot}%{_mandir}/man1/verifymedia.1

%files
%defattr(-,root,root)
%{_bindir}/*
%{_libexecdir}/%{name}
%doc README* *.md
%doc %{_mandir}/man1/mksusecd.*
%doc %{_mandir}/man1/verifymedia.*
%if %suse_version >= 1500
%license COPYING*
%else
%doc COPYING*
%endif

%changelog
* Thu Feb 20 2025 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#83
- add missing perl-JSON dependency
- rework signature test wording
- change --ignore option to accept only one argument
- 3.5
* Wed Feb 19 2025 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#82
- add verifymedia tool to check SUSE media for technical
  correctness (bsc#1236828)
- moved isohybrid into separate directory
- add sligthly stripped down version of parti
- 3.4
* Fri Feb  7 2025 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#79
- do not require root permissions to unpack ISO images (bsc#1236828)
- 3.3
* Thu Feb  6 2025 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#78
- make a more determined attempt to create the UEFI boot image if
  it is missing (bsc#1236828)
- 3.2
* Tue Feb  4 2025 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#77
- s390x: re-create initrd.off if needed (bsc#1236781)
- 3.1
* Fri Aug 16 2024 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#76
- make some compression settings configurable (bsc#1223982,
  jsc#PED-8374)
- update documentation
- fix UEFI image rebuild detection (bsc#1227668)
- allow updating kernel in live initrd
- allow updating kernel in live root, support resizing live root
- 3.0
* Wed Jul 17 2024 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#75
- update El-Torito UEFI image to match 'EFI' directory (bsc#1227668)
- 2.19
* Thu Jun  6 2024 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#74
- fix --no-joliet option and add warning about too long Joliet file
  names
- add more mkisofs log output in verbosity level 3
- ensure mksusecd error code is preserved
- add info about Joliet file name limit to man page
- 2.18
* Thu Jun  6 2024 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#73
- fix integrating software modules containing debuginfo packages
  (bsc#1226047)
- increase initrd xz compression level
- enforce de-duplication in mkisofs
- 2.17
* Fri Apr  5 2024 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#72
- deal with systems where /tmp is a symlink (bsc#1221603)
- 2.16
* Wed Mar 20 2024 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#71
- support usrmerged kmod package (bsc#1221603)
- 2.15
* Fri Jan 19 2024 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#70
- handle compressed firmware files (bsc#1214789)
- documentation update
- 2.14
* Wed Jan 10 2024 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#69
- allow also xz and zstd compression in repodata (bsc#1218706)
- 2.13
* Mon Jul 24 2023 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#67
- allow --instsys option for Live media
- calculate EFI boot image size correctly
- if initrd/kernel are in two different location on the medium,
  update in both locations
- isohybrid: remove outdated 1024 cylinders warning
- default to GPT if source ISO uses it
- add --signature-file option and rewrite signature embedding
- fix --instsys option handling (bsc#1213606)
- add --rescue option to allow modifying the rescue system
- update man page
- 2.12
* Thu Jul 13 2023 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#66
- add --volume1 option to allow setting separate labels for both
  ISO file systems (bsc#1213185)
- 2.11
* Tue Mar 21 2023 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#65
- create efi boot image, if missing
- support grub hybrid boot code
- update doc
- show missing s390x file name correctly
- adjust boot info table checksum in grub
- better warning of insufficient file permissions
- support Live media (jsc#PED-2975)
- 2.10
* Thu Dec 15 2022 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#64
- much improved usrmerge kernel support (bsc#1206181)
- 2.9
* Wed Dec  7 2022 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#63
- fix handling of usrmerge kernels (bsc#1206181)
- 2.8
* Mon May 23 2022 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#61
- fix zstd compression handling (bsc#1198138)
- 2.7
* Mon Dec  6 2021 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#60
- update documentation
- 2.6
* Mon Dec  6 2021 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#59
- support tftpboot-installation-<PRODUCT> RPMs as source
  (jsc#SLE-22669)
- 2.5
* Thu Nov 11 2021 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#58
- read list of special initrd modules from .base_modules if it exists
- 2.4
* Thu Nov 11 2021 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#57
- fix zstd compression handling
- 2.3
* Thu Nov 11 2021 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#56
- rework documentation and split off proper man page
- adjust spec file
- 2.2
* Wed Nov 10 2021 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#54
- mksusecd: add support for zstd-compressed archives and initrd
- mksusecd: support zstd compression for kernel modules
- zstd compression for initrd and kernel modules (jsc#SLE-18766,
  jsc#SLE-18768, jsc#SLE-20248, jsc#SLE-21256)
- 2.1
* Tue Nov  9 2021 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#55
- rename --instsys option to --instsys-url
- add new --initrd option for extending the installation system
- allow RPMs as media sources and add special handling for
  skelcd-installer-xxx packages
- implement instsys extending for suse and rh style media
- support updating .treeinfo files
- code to distinguish suse and rh media
- add openSUSE spec file
- require at least checkmedia version 6
- add support for rh media (jsc#SCL-6)
- 2.0
* Mon Feb 22 2021 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#53
- handle .ko.xz modules (bsc#1182573)
- 1.78
* Fri Sep 25 2020 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#52
- fix add_on_products.xml handling (bsc#1176379)
- 1.77
* Thu Sep 10 2020 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#51
- look only at top-level products file (bsc#1176176)
- ensure modified files really end up on the media (bsc#1176176)
- adjust product handling if products are spread over several media
- include complete product directories
- fix product handling with new SLE full media layout
- 1.76
* Mon Jul 27 2020 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#50
- added "--sign-pass-file"
- added option for recreating and signing the repo
- remove "all done" message
- additional passphrase options are not necessary at key creation
- set additional options only when a existing sign key is specified
- print message if --sign-pass-file and missing
- sign-key
- readded removed line
- removed sign_passwd_option on import
- changed if-else-logic when specifying a passphrasefile
- readded redirection to /dev/null
- removed a print
- removed trailing spaces
- remove a single space
- additional options
- 1.75
* Wed Jun 24 2020 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#49
- add --sign-key-id option to allow specifying a gpg signing key by id
- 1.74
* Tue Jun 23 2020 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#48
- do not include excluded products (bsc#1173263)
- recreate products file, including its checksum update
- 1.73
* Thu Apr  9 2020 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#47
- Fix broken link to kiwi documentation
- 1.72
* Tue Dec  3 2019 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#45
- choose correct kernel image name for aarch64 (bsc#1158131)
- 1.71
* Thu Aug 15 2019 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#43
- adjust boot files for s390x (bsc#1141223)
- allow to set boot options via --boot also on s390x
- 1.70
* Tue Jul 16 2019 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#42
- embed gpg signature of checksum metadata into image (bsc#1139561)
- make unsigned images the default
- 1.69
* Thu Apr 11 2019 snwint@suse.de
- merge gh#openSUSE/mksusecd#41
- add --enable-repos option
- update documentation
- 1.68
* Thu Nov 29 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Nov 27 2018 snwint@suse.de
- merge gh#openSUSE/mksusecd#40
- support aarch64 media
- 1.67
* Thu Nov 15 2018 snwint@suse.de
- merge gh#openSUSE/mksusecd#39
- add HOWTO describing some typical uses
- update git2log script
- 1.66
* Fri Sep 14 2018 snwint@suse.de
- merge gh#openSUSE/mksusecd#38
- no longer assume repo-md repositories don't include the installer
  (bsc#1093145)
- no longer assume repo-md repositories don't include the installer
  (bsc#1093145
- 1.65
* Fri Aug 31 2018 snwint@suse.de
- merge gh#openSUSE/mksusecd#37
- adjust also isozipl to isoinfo changes (bsc#1097814)
- 1.64
* Wed Aug 29 2018 snwint@suse.de
- merge gh#openSUSE/mksusecd#36
- don't forget to sign addon repository
- 1.63
* Thu Jul  5 2018 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#35
- don't miss zstd compression module (bsc#1100236)
- 1.62
* Wed Jun 27 2018 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#34
- keep some meta data for media checking even if no iso9660
  filesystem is used (#1000947)
- 1.61
* Fri Jun 15 2018 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#33
- adjust to isoinfo and syslinux changes (bsc#1097814)
- don't pass partition offset to tagmedia
- 1.60
* Fri May 25 2018 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#32
- add -joliet-long to mkisofs call as some file names on our media
  are too long (bsc#1094687)
- 1.59
* Tue May  8 2018 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#31
- added link to obs builds
- add links to related blog articles
- 1.58
* Mon May  7 2018 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#30
- fix cpio archive parser (bsc#1092147)
- 1.57
* Tue Mar  6 2018 adam.majer@suse.de
- switch to using cdrtools for Factory and SLE15. wodim is to
  be removed (bnc#1081739)
* Thu Feb 22 2018 snwint@suse.de
- adjust Requires to work also with older dists (bsc#1082057)
* Wed Feb 21 2018 snwint@suse.de
- require createrepo-implementation (bsc#1075670)
* Fri Jan 19 2018 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#29
- allow building of encrypted installation media
- fix handling of repo-md repositories with encrypted media
- 1.56
* Tue Dec  5 2017 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#28
- support new CHECKSUMS file
- 1.55
* Thu Nov 30 2017 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#26
- manage (sle15-style modules) repomd repositories
- 1.54
* Mon Oct  9 2017 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#24
- rework cpio parsing function to handle blobs added by our product
  creator
- ensure initrd has really been unpacked when --rebuild-initrd
  option is used
- beautify code
- 1.53
* Mon May 22 2017 wfeldt@opensuse.org
- merge gh#openSUSE/mksusecd#23
- remove iso9660 header when creating image for usb media
  (bsc#939456)
- clarify description of --fat option
- 1.52
* Thu May  4 2017 snwint@suse.de
- include all documentation files
* Fri Apr 28 2017 wfeldt@opensuse.org
- fix getopt config
- enhanced README.md
- merge gh#openSUSE/mksusecd#22
- document all functions
- 1.51
* Tue Apr 11 2017 wfeldt@opensuse.org
- distinguish between repomd/classical repo types and allow to
  specify the default repo location (fate#322983)
- merge gh#openSUSE/mksusecd#21
- fix typo in help text
- 1.50
* Wed Apr  5 2017 snwint@suse.com
- add support for disk images with FAT file system
- 1.49
* Mon Apr  3 2017 snwint@suse.com
- undo accidental mksusecd patch
- 1.48
* Mon Apr  3 2017 snwint@suse.com
- some small doc fixes
- add dvd/disk image layout description
- 1.47
* Mon Apr  3 2017 snwint@suse.com
- isohybrid: add --size option to specify image size
- 1.46
* Mon Mar 20 2017 snwint@suse.com
- fix typo
- add --rebuild-initrd option for smaller initrds
- 1.45
* Thu Mar 16 2017 jenkins@suse.com
- support old mksquashfs version
- 1.44
* Thu Mar 16 2017 snwint@suse.com
- fix to work with older modules.dep format (bsc#1027636)
- 1.43
* Fri Aug 12 2016 snwint@suse.com
- extended help text and added some small fixes
- fix choosing an add-on name
- be less restrictive when generating add-on aliases
- support creating add-ons on the target iso (bsc#991935)
- 1.42
* Tue Aug  2 2016 snwint@suse.com
- catch error when we fail to unpack squashfs images
- handle modules.order and modules.builtin when updating a kernel
- 1.41
* Fri Jul 15 2016 snwint@suse.com
- tw support: also sign image files
- sanitize function that removes files from iso
- remove tumbleweed images in 'micro' format
- 1.40
* Mon Jun 20 2016 snwint@suse.com
- create missing 'content' file
- 1.39
* Tue May 10 2016 snwint@suse.com
- adjust list of specially handled initrd modules
- 1.38
* Mon Jan 18 2016 snwint@suse.com
- fix typo
- 1.37
* Tue Dec  8 2015 snwint@suse.com
- add hashes for license and control file
- 1.36
* Fri Dec  4 2015 snwint@suse.com
- support uncompressed initrd (bsc#957847)
- 1.35
* Wed Oct 21 2015 snwint@suse.com
- fix ppc boot iso creation
- 1.34
* Tue Sep 29 2015 snwint@suse.com
- Add link to linux-devtools documentation
- 1.33
* Wed Aug 12 2015 snwint@suse.com
- move isozipl to /usr/bin
- make it work also with mkisofs from cdrtools
- 1.32
* Wed Aug 12 2015 snwint@suse.de
- syslinux is no longer required
* Mon Aug 10 2015 snwint@suse.com
- fix cpio unpacking bug
- 1.31
* Thu Jul 23 2015 snwint@suse.com
- integrate isozipl in mksusecd
- add some options to isohybrid to make it more flexible
- add zipl binary blobs
- 1.30
* Wed Jul 22 2015 snwint@suse.com
- added isozipl to make an iso zipl bootable
- 1.29
* Mon Jul 13 2015 snwint@suse.com
- fix cpio archive unpacking
- 1.28
* Tue Jul  7 2015 snwint@suse.com
- README: link to mkdud; grammar; formatting
- 1.27
* Mon Jul  6 2015 snwint@suse.com
- extended readme
- 1.26
* Thu Jun 25 2015 snwint@suse.com
- keep /content file up-to-date even when new files are added to the iso
- 1.25
* Fri Jun 19 2015 snwint@suse.com
- ensure '/content' is re-signed when necessary
- 1.24
* Fri Jun 19 2015 snwint@suse.com
- implement --kernel option to replace kernel & modules used for booting
- added --add-entry option to create a new boot menu entry for modifications
- 1.23
* Wed Jun  3 2015 snwint@suse.com
- work properly when different iso sources are specified
- 1.22
* Mon May 18 2015 snwint@suse.com
- get isohybrid binary location right
- 1.21
* Fri May  8 2015 snwint@suse.com
- fix key generation issues with different gpg2 versions
- 1.20
* Sat Apr 25 2015 schwab@linux-m68k.org
- Run through spec-cleaner
- Fix file list
* Thu Apr 23 2015 snwint@suse.com
- fix Makefile
- 1.19
* Thu Apr 23 2015 snwint@suse.com
- add special isohybrid variant to mksusecd package
- 1.18
* Thu Apr 23 2015 snwint@suse.com
- added ppc64 (chrp) boot support
- 1.17
* Fri Mar 27 2015 snwint@suse.com
- replace archive unpacking function
- 1.16
* Thu Mar 19 2015 snwint@suse.com
- stick to initrd compression format when extending initrd
- 1.15
* Thu Feb 26 2015 snwint@suse.com
- replace content.key with actual signing key used
- handle duplicate filenames
- 1.14
* Tue Feb 24 2015 snwint@suse.com
- support initrds with pre-sle12 key management
- support adding driver updates to initrd
- no-sign option should also prevent updating 'content' file
- 1.13
* Tue Feb 10 2015 snwint@suse.com
- simplify key handling
- 1.12
* Mon Feb  9 2015 snwint@suse.com
- allow to use a user-supplied signing key
- 1.11
* Fri Feb  6 2015 snwint@suse.com
- re-sign '/content' if necessary
- fix git2log script
- 1.10
* Mon Jan 26 2015 snwint@suse.com
- update git2log script
- 1.9
* Fri Nov 28 2014 snwint@suse.com
- add support for grub2 el-torito setups
- 1.8
* Tue Oct 28 2014 snwint_jenkins@suse.com
- wipe files we really don't want to appear on the media
- 1.7
* Tue Oct 21 2014 snwint_jenkins@suse.com
- added --no-digest option
- handle more than 2 el torito entries
- 1.6
* Mon Oct 13 2014 jenkins@suse.com
- added 'archive' Makefile target
- updated git2log script
- added '--pico' option
- 1.5
* Wed Aug 13 2014 snwint@suse.de
- support adding rpms to the initrd
- update checksums in /content file
- 1.4
* Fri May 23 2014 snwint@suse.de
- fix micro & nano options
- update help text
- 1.3
* Fri May 23 2014 snwint@suse.de
- fix package requires
* Tue Apr 29 2014 snwint@suse.de
- better import of old iso9660 metadata
- 1.2
* Mon Apr 28 2014 snwint@suse.de
- fix --micro option
- 1.1
* Mon Apr 28 2014 snwint@suse.de
- add ISO meta info
- added --micro and --nano to produce small test isos
- use exclude file instead of individual options
- fix hybrid iso creation when boot options are added
- support adding boot options
- support s390x media
- ignore isohybrid warnings
- fix file magic usage
- add 'initrd' option to add files directly to initrd
- added install target
- added README
- added help text
- support fat
- 1.0
